<?php

namespace CreoCode\ContaoPopup\Classes;

use CreoCode\ContaoPopup\Models\PopupModel;
use CreoCode\ContaoPopup\Models\PopupSetModel;

/**
 * Extension version
 */
class GeneratePage extends \Frontend
{
	/**
	 * Add the cookie information scripts
	 */
	public function addScripts()
	{
		$popup = $this->isPopupEnabled();
		if ($popup) {
            // Combine the assets
            $flag = '|static';
			$GLOBALS['TL_CSS'][] = 'bundles/contaopopup/css/popup.scss|all'.$flag;
			$GLOBALS['TL_CSS'][] = 'bundles/contaopopup/css/animate.min.css|all'.$flag;
			$GLOBALS['TL_JAVASCRIPT'][] = 'bundles/contaopopup/js/popup.js';
		}
	}


	/**
	 * Check whether a popup is enabled and should be displayed
	 *
	 * @param \PageModel $rootPage
	 *
	 * @return boolean
	 */
	protected function isPopupEnabled(\PageModel $rootPage = null)
	{
		$objRoot = ($rootPage !== null) ? $rootPage : $this->getCurrentRootPage();
		$popupSet = $objRoot->popup_set;

		global $objPage;

		if ($popupSet) {
			$popup = PopupModel::findPublishedByPid($popupSet);

			if (!$popup) {
				return false;
			}
			
			$popupArray = array();
			foreach ($popup as $popup) {
				if ($popup->pages) {
					$pages = unserialize($popup->pages);
					if (in_array($objPage->id, $pages)) {
						array_push($popupArray, $popup);
					}
				} else {
					array_push($popupArray, $popup);
				}
			}
			return $popupArray;
		}
		return false;
	}


	/**
	 * Add the cookie HTML buffer
	 * @param string
	 * @return string
	 */
	public function addPopups($strBuffer, $strTemplate)
	{		
        if(empty($strBuffer)) {
            return $strBuffer;
        }

		$popup = $this->isPopupEnabled();
		if ($popup) {

			foreach ($popup as $popup) {
				$objTemplate = new \FrontendTemplate($popup->template);
				$objTemplate->id = "popup-".$popup->id;
				$objTemplate->customId = "popup-".$popup->customId;
				$objTemplate->class = "popup";
				if ($popup->cssClass) {
					$objTemplate->class = "popup ".$popup->cssClass;
				}
				//Position settings
				$objTemplate->position = $popup->position;
				//Darken settings
				$objTemplate->darkenPage = ($popup->darkenPage !== '') ? true : false;
				$objTemplate->darkenAnimationIn = $popup->darkenAnimationIn;
				$objTemplate->darkenAnimationInSpeed = $popup->darkenAnimationInSpeed;
				$objTemplate->darkenAnimationOut = $popup->darkenAnimationOut;
				$objTemplate->darkenAnimationOutSpeed = $popup->darkenAnimationOutSpeed;
				$objTemplate->darkenerClickToClose = $popup->darkenerClickToClose;
				//Appearance settings
				$objTemplate->appearance = $popup->appearance;
				$objTemplate->delay = $popup->delay;
				$objTemplate->scrollOffset = $popup->scrollOffset;
				$objTemplate->cookieExpire = $popup->cookieExpire;
				//Animation settings
				$objTemplate->animationIn = $popup->animationIn;
				$objTemplate->animationInSpeed = $popup->animationInSpeed;
				$objTemplate->animationOut = $popup->animationOut;
				$objTemplate->animationOutSpeed = $popup->animationOutSpeed;

				// Add content to popup
				$objTemplate->text = '';
				$objTemplate->hasText = false;

				$id = $popup->id;
				$objTemplate->text = function () use ($id) {
					$strText = '';
					$objElement = \ContentModel::findPublishedByPidAndTable($id, 'tl_popup');

					if ($objElement !== null)
					{
						while ($objElement->next())
						{
							$strText .= $this->getContentElement($objElement->current());
						}
					}

					return $strText;
				};
				$objTemplate->hasText = function () use ($popup) {
					return \ContentModel::countPublishedByPidAndTable($popup->id, 'tl_popup') > 0;
				};

				//$strBuffer = $strBuffer . $objTemplate->parse();
				//$strBuffer = str_replace('</body>', $objTemplate->parse() . '</body>', $strBuffer);
				$strBuffer = $this->str_replace_last('</body>', $objTemplate->parse() . '</body>', $strBuffer);

			}

		}
		
		return $strBuffer;
	}

	/**
	 * Str replace last
	 */
	function str_replace_last($search, $replace, $subject) {
	    $pos = strrpos($subject, $search);

	    if($pos !== false)
	    {
	        $subject = substr_replace($subject, $replace, $pos, strlen($search));
	    }

	    return $subject;
	}

	/**
	 * Get the current root page and return it
	 * @return object
	 */
	protected function getCurrentRootPage()
	{
		global $objPage;
		$strKey = $objPage->rootId;
		if (!\Cache::has($strKey))
		{
			\Cache::set($strKey, \PageModel::findByPk($objPage->rootId));
		}
		return \Cache::get($strKey);
	}

}